Braulio
=======

Welcome to this documentation. This tool aims to help with the release process
of your project by handling versioning and changelogs for you. Please read the
foreword section before installing and using it.


User’s Guide
------------

.. toctree::
    :maxdepth: 2

    foreword
    docs
    configuration
    installation
    history
